@@ -1,4 +1,4 @@
 {-# LANGUAGE UnicodeSyntax #-}
 
-foo :: forall a. Show a => a -> String
+foo :: forall a. (Show a) => a -> String
 foo = const ()
