@@ -12,3 +12,7 @@ type family F a
   F Bool =
            Char
   F a    = String
+
+type family F a where
+  F a -- foo
+    = a
