@@ -16,3 +16,7 @@ type API =
   "route1" :> ApiRoute1
     :<|> "route2" :> ApiRoute2 -- comment here
     :<|> OmitDocs :> "i" :> ASomething API
+
+type A -- foo
+  =
+  B
