@@ -15,3 +15,6 @@ type API
   = "route1" :> ApiRoute1
       :<|> "route2" :> ApiRoute2 -- comment here
       :<|> OmitDocs :> "i" :> ASomething API
+
+type A -- foo
+  = B
