@@ -1,5 +1,6 @@
 a =
-  b & c .~ d
+  b
+    & c .~ d
     & e
       %~ f
         g
