@@ -12,7 +12,8 @@ import GHC.Data.EnumSet (EnumSet)
 import GHC.Hs
 import GHC.LanguageExtensions.Type
 import GHC.Types.SrcLoc
-import Ormolu.Parser.Anns
+import Ormolu.Config (SourceType)
+import Ormolu.Fixity (FixityMap, LazyFixityMap)
 import Ormolu.Parser.CommentStream
 import Ormolu.Parser.Pragma (Pragma)
 
@@ -21,20 +22,22 @@ data SourceSnippet = RawSnippet Text | ParsedSnippet ParseResult
 
 -- | A collection of data that represents a parsed module in Ormolu.
 data ParseResult = ParseResult
-  { -- | 'ParsedSource' from GHC
+  { -- | Parsed module or signature
     prParsedSource :: HsModule,
-    -- | Ormolu-specfic representation of annotations
-    prAnns :: Anns,
+    -- | Either regular module or signature file
+    prSourceType :: SourceType,
     -- | Stack header
     prStackHeader :: Maybe (RealLocated Comment),
     -- | Pragmas and the associated comments
     prPragmas :: [([RealLocated Comment], Pragma)],
     -- | Comment stream
     prCommentStream :: CommentStream,
-    -- | Whether or not record dot syntax is enabled
-    prUseRecordDot :: Bool,
     -- | Enabled extensions
     prExtensions :: EnumSet Extension,
+    -- | Fixity overrides
+    prFixityOverrides :: FixityMap,
+    -- | Fixity map for operators
+    prFixityMap :: LazyFixityMap,
     -- | Indentation level, can be non-zero in case of region formatting
     prIndent :: Int
   }
