@@ -18,7 +18,9 @@ module Ormolu.Printer.Internal
     atom,
     space,
     newline,
-    useRecordDot,
+    askSourceType,
+    askFixityOverrides,
+    askFixityMap,
     inci,
     inciHalf,
     sitcc,
@@ -49,14 +51,12 @@ module Ormolu.Printer.Internal
     setSpanMark,
     getSpanMark,
 
-    -- * Annotations
-    getAnns,
-
     -- * Extensions
     isExtensionEnabled,
   )
 where
 
+import Control.Monad
 import Control.Monad.Reader
 import Control.Monad.State.Strict
 import Data.Bool (bool)
@@ -69,10 +69,10 @@ import Data.Text.Lazy.Builder
 import GHC.Data.EnumSet (EnumSet)
 import qualified GHC.Data.EnumSet as EnumSet
 import GHC.LanguageExtensions.Type
-import GHC.Parser.Annotation
 import GHC.Types.SrcLoc
 import GHC.Utils.Outputable (Outputable)
-import Ormolu.Parser.Anns
+import Ormolu.Config (SourceType (..))
+import Ormolu.Fixity (FixityMap, LazyFixityMap)
 import Ormolu.Parser.CommentStream
 import Ormolu.Printer.SpanStream
 import Ormolu.Utils (showOutputable)
@@ -95,14 +95,18 @@ data RC = RC
     rcLayout :: Layout,
     -- | Spans of enclosing elements of AST
     rcEnclosingSpans :: [RealSrcSpan],
-    -- | Collection of annotations
-    rcAnns :: Anns,
     -- | Whether the last expression in the layout can use braces
     rcCanUseBraces :: Bool,
-    -- | Whether the source could have used the record dot preprocessor
-    rcUseRecDot :: Bool,
     -- | Enabled extensions
-    rcExtensions :: EnumSet Extension
+    rcExtensions :: EnumSet Extension,
+    -- | Whether the source is a signature or a regular module
+    rcSourceType :: SourceType,
+    -- | Fixity map overrides, kept separately because if we parametrized
+    -- 'Ormolu.Fixity.buildFixityMap' by fixity overrides it would break
+    -- memoization
+    rcFixityOverrides :: FixityMap,
+    -- | Fixity map for operators
+    rcFixityMap :: LazyFixityMap
   }
 
 -- | State context of 'R'.
@@ -166,15 +170,17 @@ runR ::
   SpanStream ->
   -- | Comment stream
   CommentStream ->
-  -- | Annotations
-  Anns ->
-  -- | Use Record Dot Syntax
-  Bool ->
+  -- | Whether the source is a signature or a regular module
+  SourceType ->
   -- | Enabled extensions
   EnumSet Extension ->
+  -- | Fixity overrides
+  FixityMap ->
+  -- | Fixity map
+  LazyFixityMap ->
   -- | Resulting rendition
   Text
-runR (R m) sstream cstream anns recDot extensions =
+runR (R m) sstream cstream sourceType extensions fixityOverrides fixityMap =
   TL.toStrict . toLazyText . scBuilder $ execState (runReaderT m rc) sc
   where
     rc =
@@ -182,10 +188,11 @@ runR (R m) sstream cstream anns recDot extensions =
         { rcIndent = 0,
           rcLayout = MultiLine,
           rcEnclosingSpans = [],
-          rcAnns = anns,
           rcCanUseBraces = False,
-          rcUseRecDot = recDot,
-          rcExtensions = extensions
+          rcExtensions = extensions,
+          rcSourceType = sourceType,
+          rcFixityOverrides = fixityOverrides,
+          rcFixityMap = fixityMap
         }
     sc =
       SC
@@ -245,7 +252,7 @@ interferingTxt = spit InterferingText
 -- literals and similar. Everything that doesn't have inner structure but
 -- does have an 'Outputable' instance.
 atom ::
-  Outputable a =>
+  (Outputable a) =>
   a ->
   R ()
 atom = spit Atom . T.pack . showOutputable
@@ -275,7 +282,7 @@ spit stype text = do
   R $ do
     i <- asks rcIndent
     c <- gets scColumn
-    closestEnclosing <- listToMaybe <$> asks rcEnclosingSpans
+    closestEnclosing <- asks (listToMaybe . rcEnclosingSpans)
     let indentedTxt = spaces <> text
         spaces = T.replicate spacesN " "
         spacesN =
@@ -378,9 +385,17 @@ newlineRaw = R . modify $ \sc ->
             _ -> AfterNewline
         }
 
--- | Return 'True' if we should print record dot syntax.
-useRecordDot :: R Bool
-useRecordDot = R (asks rcUseRecDot)
+-- | Return the source type.
+askSourceType :: R SourceType
+askSourceType = R (asks rcSourceType)
+
+-- | Retrieve fixity overrides map.
+askFixityOverrides :: R FixityMap
+askFixityOverrides = R (asks rcFixityOverrides)
+
+-- | Retrieve the lazy fixity map.
+askFixityMap :: R LazyFixityMap
+askFixityMap = R (asks rcFixityMap)
 
 inciBy :: Int -> R () -> R ()
 inciBy step (R m) = R (local modRC m)
@@ -566,15 +581,6 @@ setSpanMark spnMark = R . modify $ \sc ->
 getSpanMark :: R (Maybe SpanMark)
 getSpanMark = R (gets scSpanMark)
 
-----------------------------------------------------------------------------
--- Annotations
-
--- | For a given span return 'AnnKeywordId's associated with it.
-getAnns ::
-  SrcSpan ->
-  R [AnnKeywordId]
-getAnns spn = lookupAnns spn <$> R (asks rcAnns)
-
 ----------------------------------------------------------------------------
 -- Helpers for braces
 
