@@ -10,6 +10,7 @@ module Ormolu.Processing.Preprocess
 where
 
 import Control.Monad
+import Data.Array as A
 import Data.Bifunctor (bimap)
 import Data.Char (isSpace)
 import Data.Function ((&))
@@ -31,7 +32,7 @@ preprocess ::
   -- | Whether CPP is enabled
   Bool ->
   RegionDeltas ->
-  String ->
+  Text ->
   [Either Text RegionDeltas]
 preprocess cppEnabled region rawInput = rawSnippetsAndRegionsToFormat
   where
@@ -47,9 +48,9 @@ preprocess cppEnabled region rawInput = rawSnippetsAndRegionsToFormat
     interleave' = case regionsNotToFormat of
       r : _ | regionPrefixLength r == 0 -> interleave
       _ -> flip interleave
-    rawSnippets = T.pack . flip linesInRegion updatedInput <$> regionsNotToFormat
+    rawSnippets = flip linesInRegion updatedInput <$> regionsNotToFormat
       where
-        updatedInput = unlines . fmap updateLine . zip [1 ..] . lines $ rawInput
+        updatedInput = T.unlines . fmap updateLine . zip [1 ..] . T.lines $ rawInput
         updateLine (i, line) = IntMap.findWithDefault line i replacementLines
     rawSnippetsAndRegionsToFormat =
       interleave' (Left <$> rawSnippets) (Right <$> regionsToFormat)
@@ -63,26 +64,29 @@ preprocess cppEnabled region rawInput = rawSnippetsAndRegionsToFormat
     -- Extraneous raw snippets at the start/end are dropped afterwards.
     patchSeparatingBlankLines = \case
       Right r@RegionDeltas {..} ->
-        if all isSpace (linesInRegion r rawInput)
+        if T.all isSpace (linesInRegion r rawInput)
           then [blankRawSnippet]
           else
-            [blankRawSnippet | isBlankLine regionPrefixLength] <> [Right r]
+            [blankRawSnippet | isBlankLine regionPrefixLength]
+              <> [Right r]
               <> [blankRawSnippet | isBlankLine (rawLineLength - regionSuffixLength - 1)]
       Left r -> [Left r]
       where
         blankRawSnippet = Left "\n"
-        isBlankLine i = isJust . mfilter (all isSpace) $ rawLines !!? i
+        isBlankLine i = isJust . mfilter (T.all isSpace) $ rawLines !!? i
     isBlankRawSnippet = \case
       Left r | T.all isSpace r -> True
       _ -> False
 
-    rawLines = lines rawInput
+    rawLines = A.listArray (0, length rawLines' - 1) rawLines'
+      where
+        rawLines' = T.lines rawInput
     rawLineLength = length rawLines
 
     interleave [] bs = bs
     interleave (a : as) bs = a : interleave bs as
 
-    xs !!? i = if i >= 0 && i < length xs then Just $ xs !! i else Nothing
+    xs !!? i = if A.bounds rawLines `A.inRange` i then Just $ xs A.! i else Nothing
 
 -- | All lines we are not supposed to format, and a set of replacements
 -- for specific lines.
@@ -90,15 +94,15 @@ linesNotToFormat ::
   -- | Whether CPP is enabled
   Bool ->
   RegionDeltas ->
-  String ->
-  (IntSet, IntMap String)
+  Text ->
+  (IntSet, IntMap Text)
 linesNotToFormat cppEnabled region@RegionDeltas {..} input =
   (unconsidered <> magicDisabled <> otherDisabled, lineUpdates)
   where
     unconsidered =
       IntSet.fromAscList $
         [1 .. regionPrefixLength] <> [totalLines - regionSuffixLength + 1 .. totalLines]
-    totalLines = length (lines input)
+    totalLines = length (T.lines input)
     regionLines = linesInRegion region input
     (magicDisabled, lineUpdates) = magicDisabledLines regionLines
     otherDisabled = (mconcat allLines) regionLines
@@ -115,19 +119,19 @@ data OrmoluState
 
 -- | All lines which are disabled by Ormolu's magic comments,
 -- as well as normalizing replacements.
-magicDisabledLines :: String -> (IntSet, IntMap String)
+magicDisabledLines :: Text -> (IntSet, IntMap Text)
 magicDisabledLines input =
   bimap IntSet.fromAscList IntMap.fromAscList . mconcat $
-    go OrmoluEnabled (lines input `zip` [1 ..])
+    go OrmoluEnabled (T.lines input `zip` [1 ..])
   where
     go _ [] = []
     go state ((line, i) : ls)
-      | isMagicComment ormoluDisable line,
+      | Just rest <- isMagicComment ormoluDisable line,
         state == OrmoluEnabled =
-        ([i], [(i, magicComment ormoluDisable)]) : go OrmoluDisabled ls
-      | isMagicComment ormoluEnable line,
+          ([i], [(i, magicComment ormoluDisable <> rest)]) : go OrmoluDisabled ls
+      | Just rest <- isMagicComment ormoluEnable line,
         state == OrmoluDisabled =
-        ([i], [(i, magicComment ormoluEnable)]) : go OrmoluEnabled ls
+          ([i], [(i, magicComment ormoluEnable <> rest)]) : go OrmoluEnabled ls
       | otherwise = iIfDisabled : go state ls
       where
         iIfDisabled = case state of
@@ -135,41 +139,39 @@ magicDisabledLines input =
           OrmoluEnabled -> ([], [])
 
 -- | All lines which satisfy a predicate.
-linesFiltered :: (String -> Bool) -> String -> IntSet
+linesFiltered :: (Text -> Bool) -> Text -> IntSet
 linesFiltered p =
-  IntSet.fromAscList . fmap snd . filter (p . fst) . (`zip` [1 ..]) . lines
+  IntSet.fromAscList . fmap snd . filter (p . fst) . (`zip` [1 ..]) . T.lines
 
 -- | Lines which contain a shebang.
-shebangLines :: String -> IntSet
-shebangLines = linesFiltered ("#!" `L.isPrefixOf`)
+shebangLines :: Text -> IntSet
+shebangLines = linesFiltered ("#!" `T.isPrefixOf`)
 
 -- | Lines which contain a LINE pragma.
-linePragmaLines :: String -> IntSet
-linePragmaLines = linesFiltered ("{-# LINE" `L.isPrefixOf`)
+linePragmaLines :: Text -> IntSet
+linePragmaLines = linesFiltered ("{-# LINE" `T.isPrefixOf`)
 
 -- | Inner text of a magic enabling marker.
-ormoluEnable :: String
+ormoluEnable :: Text
 ormoluEnable = "ORMOLU_ENABLE"
 
 -- | Inner text of a magic disabling marker.
-ormoluDisable :: String
+ormoluDisable :: Text
 ormoluDisable = "ORMOLU_DISABLE"
 
 -- | Creates a magic comment with the given inner text.
-magicComment :: String -> String
+magicComment :: Text -> Text
 magicComment t = "{- " <> t <> " -}"
 
 -- | Construct a function for whitespace-insensitive matching of string.
 isMagicComment ::
   -- | What to expect
-  String ->
+  Text ->
   -- | String to test
-  String ->
-  -- | Whether or not the two strings watch
-  Bool
-isMagicComment expected s0 = isJust $ do
-  let trim = dropWhile isSpace
-  s1 <- trim <$> L.stripPrefix "{-" (trim s0)
-  s2 <- trim <$> L.stripPrefix expected s1
-  s3 <- L.stripPrefix "-}" s2
-  guard (all isSpace s3)
+  Text ->
+  -- | If the two strings match, we return the rest of the line.
+  Maybe Text
+isMagicComment expected s0 = do
+  s1 <- T.stripStart <$> T.stripPrefix "{-" (T.stripStart s0)
+  s2 <- T.stripStart <$> T.stripPrefix expected s1
+  T.stripPrefix "-}" s2
